#
# spec file for package nitrogen
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nitrogen
Version:        1.6.1
Release:        1.23
Summary:        A background browser and setter for X windows
License:        GPL-2.0-only AND CC-BY-SA-3.0
Group:          System/X11/Utilities
Url:            http://projects.l3ib.org/nitrogen/
Source0:        http://projects.l3ib.org/nitrogen/files/%{name}-%{version}.tar.gz
Source1:        %{name}.desktop
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gtkmm2-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(xinerama)
Requires:       hicolor-icon-theme
Recommends:     %{name}-lang
%lang_package

%description

Nitrogen is a background browser and setter for X windows. It is written
in C++ using the gtkmm toolkit. It can be used in two modes: browser and
recall. Some of the features are:

* Multihead and Xinerama aware.
* Recall mode to used via startup script.
* Uses freedesktop.org standard for thumbnails.
* Can set GNOME background.
* Command line set modes for script use.
* Inotify monitoring of browse directory.
* Lazy loading of thumbnails - conserves memory .
* "Automatic" set mode - determines best mode to set an image based on
  its size.
* Display preview images in a tiled icon layout

%prep
%setup -q

%build
autoreconf -fiv
%configure
make %{?_smp_mflags}

%install
%make_install
install -D -m 644 data/icons/%{name}-48.png %{buildroot}/%{_datadir}/pixmaps/%{name}.png

%suse_update_desktop_file %{name} Settings DesktopSettings

%fdupes  %{buildroot}/

%find_lang %{name}

%files lang -f %{name}.lang
%{_datadir}/locale/*/LC_MESSAGES/nitrogen.mo

%files
%license COPYING
%doc AUTHORS README ChangeLog NEWS
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/*/*.png
%{_datadir}/pixmaps/%{name}.png
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_datadir}/appdata/nitrogen.appdata.xml

%changelog
* Wed May 23 2018 mvetter@suse.com
- Update to 1.6.1:
  * Root window detection for windows such as conky fixed (#40, #90, #88, #86, #89)
  * Fixed Mutter detection, added wrapped mode for mutter (#78)
  * Respect $PREFIX for application data (@berkley4, #70)
  * Don't set show desktop key for Nemo (#91)
  * No-op when Apply is pressed and nothing is selected (#92)
  * Translations now install again (#64)
  * Xinerama disabled compilation fix (@jer-gentoo, #84)
  * Random codepath if statement fix (#85)
  * README spelling error (@gfa, #82)
- Changes for 1.6.0:
  New features:
  * Keyboard shortcuts (#10)
  * Select head on command line with (--head) (@jaypikay, #13)
  * Exit confirmation dialog (@jameh, #33)
  * Can restore original background in X if changes not confirmed
  * Sorting and recursion pref options (@easysid, #47, #23)
  * Icon view with captions (#15)
  * Random background selector (Ctrl+R or --random)
  * Mutter support (#61)
  * LXDE support (#63, #80)
  * SVG image file support (@Vladimir-csp, #75)
  Issues fixed:
  * Autotools issue with X11 (#12)
  * Add desktop file (@andrewsomething, @Vladimir-csp, #28, #29, #74)
  * Freedesktop spec fix (@EvanPurkhiser, #30)
  * Nautilus detection fixes (#52, #59)
  * XDG system dir fix (Unit193, #41)
  * Don't let Xinerama mode set heads that don't exist (#55)
  * Xinerama fullscreen issue/detection (#59)
  * Man pages (#20)
  Internal:
  * Major refactor of setter code/organization, easier to support external background setters (gnome/lxde/xfce etc) (#25)
  * Autotools refactor (@JamesNZ/@JamesWrigley, #42, #45)
  * Whitespace cleanup (@jubalh, #56)
  * Notes for packagers about C++11 (@rtlanceroad, #65)
- Add language package
- Add appdata file
- Remove iconcach and desktop file update in post/postun
- Remove x11_linking.patch: upstreamed
* Fri Sep  4 2015 mpluskal@suse.com
- Use url for source
- Use macro for configure
- Add patch x11_linking.patch to fix linking
- Cleanup spec file with spec-cleaner
* Wed Nov  7 2012 toganm@opensuse.org
- Changed licence to GPL-2.0 and CC-BY-SA-3.0 (bnc#788553)
* Wed Sep  5 2012 toganm@opensuse.org
- initial checkin
